@@ -1,25 +1,7 @@
-### $Id: modelStruct.R,v 1.2 2001/01/10 19:04:03 bates Exp $
-###
 ###         modelStruct - a virtual class of model structures
 ###
-### Copyright 1997-2001  Jose C. Pinheiro <jcp@research.bell-labs.com>,
+### Copyright 1997-2003  Jose C. Pinheiro <Jose.Pinheiro@pharma.novartis.com>,
 ###                      Douglas M. Bates <bates@stat.wisc.edu>
-###
-### This file is part of the nlme library for S and related languages.
-### It is made available under the terms of the GNU General Public
-### License, version 2, or at your option, any later version,
-### incorporated herein by reference.
-###
-### This program is distributed in the hope that it will be
-### useful, but WITHOUT ANY WARRANTY; without even the implied
-### warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-### PURPOSE.  See the GNU General Public License for more
-### details.
-###
-### You should have received a copy of the GNU General Public
-### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
 
 ### Constructor
 ### There is no constructor function for this class (i.e. no function
@@ -31,13 +13,13 @@
 ###*# Methods for standard generics
 
 coef.modelStruct <-
-  function(object, unconstrained = TRUE)
+  function(object, unconstrained = TRUE, ...)
 {
   unlist(lapply(object, coef, unconstrained))
 }
 
 "coef<-.modelStruct" <-
-  function(object, value)
+  function(object, ..., value)
 {
   value <- as.numeric(value)
   parMap <- attr(object, "pmap")
@@ -50,9 +32,9 @@ coef.modelStruct <-
 }
 
 formula.modelStruct <-
-  function(object)
+  function(x, ...)
 {
-  lapply(object, formula)
+  lapply(x, formula)
 }
 
 needUpdate.modelStruct <-
@@ -76,7 +58,7 @@ print.summary.modelStruct <-
 }
 
 recalc.modelStruct <-
-  function(object, conLin = attr(object, "conLin"))
+  function(object, conLin = attr(object, "conLin"), ...)
 {
   for(i in rev(seq(along = object))) {
     conLin <- recalc(object[[i]], conLin)
@@ -86,15 +68,16 @@ recalc.modelStruct <-
 }
 
 summary.modelStruct <-
-  function(object)
+  function(object, ...)
 {
   value <- lapply(object, summary)
   class(value) <- "summary.modelStruct"
   value
 }
+
 ## will not work as it is. fitted needs more than one argument!
 update.modelStruct <-
-  function(object, data)
+  function(object, data, ...)
 {
   if (needUpdate(object)) {
     object[] <- lapply(object, update, c(list("." = object), as.list(data)))
