@@ -1,25 +1,7 @@
-### $Id: reStruct.R,v 1.6.2.1 2002/08/09 19:45:29 bates Exp $
-###
 ###      Methods for the class of random-effects structures.
 ###
-### Copyright 1997-2001  Jose C. Pinheiro <jcp@research.bell-labs.com>,
+### Copyright 1997-2003  Jose C. Pinheiro <Jose.Pinheiro@pharma.novartis.com>,
 ###                      Douglas M. Bates <bates@stat.wisc.edu>
-###
-### This file is part of the nlme library for S and related languages.
-### It is made available under the terms of the GNU General Public
-### License, version 2, or at your option, any later version,
-### incorporated herein by reference.
-###
-### This program is distributed in the hope that it will be
-### useful, but WITHOUT ANY WARRANTY; without even the implied
-### warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-### PURPOSE.  See the GNU General Public License for more
-### details.
-###
-### You should have received a copy of the GNU General Public
-### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
 
 ##*## Generics that should be implemented for any reStruct class
 
@@ -186,7 +168,7 @@ coef.reStruct <-
 }
 
 "coef<-.reStruct" <-
-  function(object, value)
+  function(object, ..., value)
 {
   if (is.null(plen <- attr(object, "plen"))) {
     stop(paste("Cannot change the parameter when",
